==> haskell-unagi-streams-0.2.7-37-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unagi-streams.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unagi-streams
version:              0.2.7
visibility:           public
id:                   unagi-streams-0.2.7-5hf3wOvgM7K8JkooLiUrl4
key:                  unagi-streams-0.2.7-5hf3wOvgM7K8JkooLiUrl4
license:              BSD-3-Clause
copyright:            Bitnomial, Inc. (c) 2016
maintainer:           luke@bitnomial.com
author:               Luke Hoersten
homepage:             https://github.com/bitnomial/unagi-streams
synopsis:             Unagi Chan IO-Streams
description:
    Io-streams chans implemented underneath with
    unagi-chans. This library is a straight port of
    the default io-streams chan implementation.

category:             IO-Streams, Concurrency
abi:                  ebafe7b759052eb10cbc2c68f58d0e43
exposed:              True
exposed-modules:
    System.IO.Streams.Concurrent.Unagi
    System.IO.Streams.Concurrent.Unagi.Bounded

import-dirs:          /usr/lib/ghc-9.0.2/site-local/unagi-streams-0.2.7
library-dirs:         /usr/lib/ghc-9.0.2/site-local/unagi-streams-0.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unagi-streams
hs-libraries:         HSunagi-streams-0.2.7-5hf3wOvgM7K8JkooLiUrl4
depends:
    base-4.15.1.0 io-streams-1.5.2.2-Lmkws98w4gpLc9KLAUqApR
    unagi-chan-0.4.1.4-H7ihq7B2WW5llUN0WAz81

haddock-interfaces:
    /usr/share/doc/haskell-unagi-streams/html/unagi-streams.haddock

haddock-html:         /usr/share/doc/haskell-unagi-streams/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unagi-streams-0.2.7-43-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unagi-streams.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unagi-streams
version:              0.2.7
visibility:           public
id:                   unagi-streams-0.2.7-LpUXN7RgK0h4SI3OAckxtT
key:                  unagi-streams-0.2.7-LpUXN7RgK0h4SI3OAckxtT
license:              BSD-3-Clause
copyright:            Bitnomial, Inc. (c) 2016
maintainer:           luke@bitnomial.com
author:               Luke Hoersten
homepage:             https://github.com/bitnomial/unagi-streams
synopsis:             Unagi Chan IO-Streams
description:
    Io-streams chans implemented underneath with
    unagi-chans. This library is a straight port of
    the default io-streams chan implementation.

category:             IO-Streams, Concurrency
abi:                  1ca6a4a227403add55b774dcfb57b2d1
exposed:              True
exposed-modules:
    System.IO.Streams.Concurrent.Unagi
    System.IO.Streams.Concurrent.Unagi.Bounded

import-dirs:          /usr/lib/ghc-9.0.2/site-local/unagi-streams-0.2.7
library-dirs:         /usr/lib/ghc-9.0.2/site-local/unagi-streams-0.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unagi-streams
hs-libraries:         HSunagi-streams-0.2.7-LpUXN7RgK0h4SI3OAckxtT
depends:
    base-4.15.1.0 io-streams-1.5.2.2-1wCAs34kxNz1zCeJqWszp1
    unagi-chan-0.4.1.4-2o35jPiVteODVUxVxy4v9K

haddock-interfaces:
    /usr/share/doc/haskell-unagi-streams/html/unagi-streams.haddock

haddock-html:         /usr/share/doc/haskell-unagi-streams/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
